@@ -20,11 +20,11 @@ def load(
             print_json(data=None)
         else:
             rich_inspect(None)
-        typer.Exit(0)
+        raise typer.Exit(0)
 
     except NotImplementedError as exc:
         typer.echo(exc)
-        typer.Exit(1)
+        raise typer.Exit(1)
 
 
 @app.command()
@@ -40,11 +40,11 @@ def dump(
             print_json(data=cleanup_dict(data))
         else:
             rich_inspect(demo_obj)
-        typer.Exit(0)
+        raise typer.Exit(0)
 
     except ValueError as exc:
         typer.echo(exc)
-        typer.Exit(1)
+        raise typer.Exit(1)
 
 
 if __name__ == "__main__":
